@@ -1,8 +1,9 @@
-package LSF::JobManager; $VERSION = 0.3;
+package LSF::JobManager; $VERSION = 0.4;
 
 use strict;
 use warnings;
 use base qw( LSF );
+use IPC::Run qw( start pump finish );
 use LSF::Job;
 
 sub import{
@@ -45,24 +46,31 @@ sub submit{
 # the terminal) and a dependancy expression that tests that all
 # the previously submitted LSF jobs have ended (any exit status)
 sub wait_all_children{
-    my ($this) = @_;
+    my ($this,$custom_dependancy) = @_;
     my @jobs = $this->jobs;
     unless(@jobs){
         warn "No LSF::Job's in this LSF::Manager\n" if $this->PrintError;
         return;
     }
-    my ($dependancy,$jobs);
-    for(@jobs){
-        $dependancy .= "ended($_)&&";
-        $jobs .= "$_ ";
+    my $dependancy;
+    if($custom_dependancy){
+        $dependancy = $custom_dependancy;
+    }else{
+        for(@jobs){
+            $dependancy .= "ended($_)&&";
+        }
+        $dependancy =~ s/\&\&$//;
     }
-    $dependancy =~ s/\&\&$//;
-    $jobs =~ s/ $//;
-    my $job = $this->submit('-I',-w => $dependancy,"echo LSF::JobManager waiting for $jobs");
-    delete $this->{-jobs}->{"$job"} if $job;
+    
+    my $job = LSF::Job->submit_top( new_flags( [ $this->params ],['-I',-w => $dependancy])
+                                              ,"echo LSF::JobManager finished waiting for " . scalar @jobs . " jobs" );
     
     # batch run the history of each job b/c its much quicker this way.
-    my @history = LSF::JobHistory->new(@jobs);
+    # because we may have more jobs than the arg list allows then we have a 
+    # second syntax for calling LSF::JobHistory->new
+    # if the first argument is and array reference then 
+    # see JobHistory.pm for details but basically we use xargs
+    my @history = LSF::JobHistory->new([],@jobs);
     my %jobs = %{ $this->{-jobs} };
     for my $hist (@history){
         $jobs{$hist->id}->{-cached_history} = $hist;
@@ -194,9 +202,16 @@ call. The required argument is the command line to submit. Optional arguments
 override the defaults given to C<new>. The submitted LSF::Job object is returned
 on success, otherwise undef is returned, $? and $@ set. See C<LSF::Job>
 
-=item $manager->wait_all_children()
+=item $manager->wait_all_children( [ DEPENDANCY ] )
 
-Waits for all previously submitted LSF Jobs to complete in a blocking manner
+Waits for all previously submitted LSF Jobs to complete in a blocking manner.
+
+If a dependancy expression is provided then this is used in preference to 
+an autogenerated dependancy based on the job id's of all the submitted jobs.
+In conjunction with named jobs ( the -J flag ) this can be used to get around
+the shell arg length limit which can be hit by extremely long dependancy 
+expressions. See the L<bsub> documentation for details of job names and 
+depenancy expressions
 
 =item $manager->params( [ [ PARAMS ] ] )
 
